---

slug: /deploy-embedded-seekdb
---

# Embedded mode

seekdb provides an embedded deployment method that runs as a "library" inside your application. It can easily run on various "endpoints", making it suitable for mobile application development, desktop application development, and application development on IoT and edge devices.

You can deploy embedded seekdb through pyseekdb (the Python SDK provided by seekdb) or Python.

## Environment requirements

* **Supported operating systems**: Linux (glibc >= 2.28)

* **Supported Python versions**:

  * **Use seekdb via pyseekdb**: Python 3.11 to 3.13

  * **Use seekdb via Python**: CPython 3.8 to 3.14

* **Supported system architectures**: x86_64, aarch64

You can run the following command to check whether your environment meets the requirements.

```python
python3 -c 'import sys;import platform; print(f"Python: {platform.python_implementation()} {platform.python_version()}, System: {platform.system()} {platform.machine()}, {platform.libc_ver()[0]}: {platform.libc_ver()[1]}");'
```

The following result is returned:

```python
Python: CPython 3.8.17, System: Linux x86_64, glibc: 2.32
```

## Deploy seekdb using pyseekdb

Use pip to install, which automatically loads embedded seekdb. The specific commands are as follows.

```shell
pip install pyseekdb
# Or specify an installation source for faster installation
pip install pyseekdb -i https://pypi.tuna.tsinghua.edu.cn/simple
```

## Considerations

If you are prompted that the pip version is too low when deploying seekdb, upgrade pip first before installing.

```bash
pip install --upgrade pip
```